#!/bin/bash
# This script creates a temporary python workspace directory, where the
# openlmi-scripts and all specified commands are installed in order for
# sphinx-build to successfuly find them and generate devel documentation out of
# them.
#
# There are several environment variables affecting the execution:
#   * SPHINXBUILD
#           sphinx binary generating the documentation

SPHINXBUILD=${SPHINXBUILD:-sphinx-build}
SRCDIR="${SRCDIR:-../../cli}"
WITH_COMMANDS="${WITH_COMMANDS:-0}"

# exit upon error at once
set -e

tmp=`mktemp -d`
export PYTHONPATH=$tmp

pushd "$SRCDIR"
python setup.py develop --install-dir=$tmp
popd  # ..

if [ "$WITH_COMMANDS" == 1 ]; then
    echo "Installing commands"
    pushd "$OPENLMI_SCRIPTS_DIR/commands"
    if [[ -z "$COMMANDS" ]]; then
        COMMANDS=`find . -maxdepth 1 -mindepth 1 -type d | sort`
    fi
    for cmd in $COMMANDS; do
        pushd $cmd
        python setup.py develop --install-dir=$tmp
        popd
    done
    popd
fi

echo "Running: ${SPHINXBUILD} $@"
${SPHINXBUILD} "$@"
rm -rf $tmp
